<?php

namespace Convoy\Jobs\Server;

use Closure;
use Convoy\Models\Server;
use Convoy\Services\Servers\Backups\PurgeBackupsService;
use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\Middleware\SkipIfBatchCancelled;
use Illuminate\Queue\Middleware\WithoutOverlapping;
use Illuminate\Queue\SerializesModels;

class PurgeBackupsJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels, Batchable;

    public $timeout = 300;

    public $tries = 10;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(protected int $serverId, protected ?Closure $callback = null)
    {
        //
    }

    public function middleware(): array
    {
        return [new SkipIfBatchCancelled, new WithoutOverlapping("server:backups.purge-{$this->serverId}")];
    }

    /**
     * Execute the job.
     */
    public function handle(PurgeBackupsService $service): void
    {
        $server = Server::findOrFail($this->serverId);

        $service->handle($server);

        if ($this->callback !== null) {
            call_user_func($this->callback);
        }
    }
}
