import getServer, { Server } from '@/api/server/getServer'
import getStatus, { ServerStateData } from '@/api/server/getState'
import { action, Action, createContextStore, thunk, Thunk } from 'easy-peasy'
import isEqual from 'react-fast-compare'

export interface ServerDataStore {
    data?: Server
    setServer: Action<ServerDataStore, Server>
    getServer: Thunk<ServerDataStore, string>
}

const server: ServerDataStore = {
    data: undefined,
    setServer: action((state, payload) => {
        if (!isEqual(payload, state.data)) {
            state.data = payload
        }
    }),
    getServer: thunk(async (actions, uuid) => {
        const server = await getServer(uuid)

        actions.setServer(server)
    }),
}

export interface ServerStatusStore {
    data?: ServerStateData
    getStatus: Thunk<ServerStatusStore, string>
    setStatus: Action<ServerStatusStore, ServerStateData>
}

const status: ServerStatusStore = {
    data: undefined,
    getStatus: thunk(async (actions, uuid) => {
        const status = await getStatus(uuid)

        actions.setStatus(status)
    }),

    setStatus: action((state, payload) => {
        if (!isEqual(payload, state.data)) {
            state.data = payload
        }
    }),
}

interface ServerStore {
    server: ServerDataStore
    status: ServerStatusStore
    clearServerState: Action<ServerStore>
}

export const ServerContext = createContextStore<ServerStore>({
    server,
    status,
    clearServerState: action(state => {
        state.server.data = undefined
        state.status.data = undefined
    }),
})
